type CookieOptions = {
    name: string;
    value: string;
    domain?: string;
    path?: string;
    /**
     * Expires | Max-Age(seconds or Date Object or Date string)
     */
    expires?: number | string | Date;
    httpOnly?: boolean;
    secure?: boolean;
    partitioned?: boolean;
    sameSite?: "Strict" | "Lax" | "None" | boolean;
    priority?: "Low" | "Medium" | "High";
};
type OptionalCookieOptions = Omit<CookieOptions, "name" | "value">;

declare const Cookies: {
    get: (name?: string) => string | Record<string, string> | undefined;
    set: (...args: [string, string, OptionalCookieOptions?] | [CookieOptions]) => false | undefined;
    remove: (name: string, path?: string, domain?: string) => void;
    has: (name: string) => boolean;
    keys: () => string[];
};

export { Cookies as default };
export type { CookieOptions, OptionalCookieOptions };
