const Cookies = {
    get: function (name) {
        if (typeof document === "undefined" || (arguments.length && !name)) {
            return;
        }
        const cookies = document?.cookie?.split("; ") ?? [];
        const allCookies = {};
        for (const cookie of cookies) {
            const parts = cookie.split("=");
            const value = decodeURIComponent(parts.slice(1).join("="));
            const key = decodeURIComponent(parts[0]);
            if (!(key in allCookies)) {
                allCookies[key] = value;
            }
            if (name === key) {
                break;
            }
        }
        return name ? allCookies[name] : allCookies;
    },
    set: function (...args) {
        const [param1, param2, param3] = args;
        const length = args.length;
        let params = {
            name: "",
            value: "",
        };
        if (length === 1) {
            params = param1;
        }
        else if (length === 2) {
            params = {
                name: param1,
                value: param2,
            };
        }
        else {
            params = {
                name: param1,
                value: param2,
                ...param3,
            };
        }
        const { name, value, path = "/", domain, sameSite, secure, expires, httpOnly, partitioned, priority, } = params;
        if (!name || typeof document === "undefined") {
            return false;
        }
        let sExpires = "";
        if (expires) {
            switch (expires.constructor) {
                // seconds
                case Number:
                    sExpires =
                        expires === Infinity
                            ? "; expires=Fri, 31 Dec 9999 23:59:59 GMT"
                            : "; max-age=" + expires;
                    break;
                case String:
                    sExpires = "; expires=" + expires;
                    break;
                case Date:
                    sExpires = "; expires=" + expires.toUTCString();
                    break;
            }
        }
        document.cookie =
            encodeURIComponent(name) +
                "=" +
                encodeURIComponent(value) +
                sExpires +
                (domain ? "; domain=" + domain : "") +
                (path ? "; path=" + path : "") +
                (secure ? "; secure" : "") +
                (sameSite
                    ? typeof sameSite === "boolean"
                        ? "; samesite=Strict"
                        : "; samesite=" + sameSite
                    : "") +
                (priority ? "; priority=" + priority : "") +
                (httpOnly ? "; httponly" : "") +
                (partitioned ? "; partitioned" : "");
    },
    remove: function (name, path, domain) {
        this.set(name, "", { path, domain, expires: -1 });
    },
    has: function (name) {
        return !!this.get(name);
    },
    keys: function () {
        return Object.keys(this.get());
    },
};

export { Cookies as default };
